@@ -152,7 +152,9 @@ class ClInstallAction(Action):
          'message': __("Would you like to reboot your computer "
                        "now to complete the installation?"),
          'confirm': 'no',
-         'condition': lambda dv: dv.Get('os_install_pxe') == 'off'},
+         'condition': lambda Get: (Get('os_install_pxe') == 'off' and
+                                   Get('os_install_root_type') != "flash")
+         },
         # перезагрузить компьютер
         {'name': 'reboot',
          'message': __("System reboot"),
