@@ -144,9 +144,8 @@ class VariableOsInstallLocaleLang(LocaleVariable):
         return self.Get('os_locale_lang')
 
     def choice(self):
-        return sorted(zip(self.Get('os_lang'),
-                          map(str, self.Get('os_lang', humanreadable=True))),
-                      key=itemgetter(0))
+        return zip(self.Get('os_lang'),
+                          map(str, self.Get('os_lang', humanreadable=True)))
 
 
 class VariableOsInstallLocaleLanguage(LocaleVariable):
