@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -31,11 +31,11 @@ from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
 from crypt import crypt
 from calculate.lib.encrypt import encrypt
-import calculate.lib.cl_template as cl_template
+import calculate.lib.cl_ini_parser as cl_ini_parser
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 
-setLocalTranslate('cl_install3',sys.modules[__name__])
+setLocalTranslate('cl_install3', sys.modules[__name__])
 
 
 class UserHelper(VariableInterface):
@@ -54,11 +54,12 @@ class UserHelper(VariableInterface):
             return _("Autologin is available for Xorg sessions only")
         return ""
 
+
 class VariableOsInstallScratch(ReadonlyVariable):
     """
     Install system in scratch mode
     """
-    type  = "bool"
+    type = "bool"
     opt = ['--build']
 
     def get(self):
@@ -68,6 +69,7 @@ class VariableOsInstallScratch(ReadonlyVariable):
         else:
             return self.Get('os_scratch')
 
+
 class VariableOsFormatType(ReadonlyVariable):
     """
     Filesystem format support by calcualte-install
@@ -78,6 +80,7 @@ class VariableOsFormatType(ReadonlyVariable):
         """Filesystem format support by calcualte-install"""
         return FileSystemManager.supportFS.keys()
 
+
 class VariableOsFormatUse(ReadonlyVariable):
     """
     Avialable format by mkfs utility
@@ -88,16 +91,17 @@ class VariableOsFormatUse(ReadonlyVariable):
         'type': "bool",
         'value': "off"}
 
-    def checkFunc(self,fs):
+    def checkFunc(self, fs):
         if "format" in FileSystemManager.supportFS[fs] and \
-               path.exists(FileSystemManager.supportFS[fs]["format"]):
+                path.exists(FileSystemManager.supportFS[fs]["format"]):
             return "yes"
         return "no"
 
     def get(self):
         return map(self.checkFunc, self.Get('os_format_type'))
 
-class VariableClMigrateRootPwd(UserHelper,Variable):
+
+class VariableClMigrateRootPwd(UserHelper, Variable):
     """
     Root password
     """
@@ -111,10 +115,10 @@ class VariableClMigrateRootPwd(UserHelper,Variable):
         self.label = _("Root password")
 
     def get(self):
-        rootPasswd = map(lambda x:x[1],
-                     filter("root".__eq__,
-                     map(lambda x:x.split(':')[0:2],
-                     readLinesFile('/etc/shadow'))))
+        rootPasswd = map(lambda x: x[1],
+                         filter("root".__eq__,
+                                map(lambda x: x.split(':')[0:2],
+                                    readLinesFile('/etc/shadow'))))
         if rootPasswd:
             rootPasswd = rootPasswd[0]
         else:
@@ -126,7 +130,7 @@ class VariableClMigrateRootPwd(UserHelper,Variable):
                 rootPasswd = ""
         return rootPasswd or ""
 
-    def set(self,value):
+    def set(self, value):
         """
         Encrypt password
         """
@@ -138,13 +142,14 @@ class VariableClMigrateRootPwd(UserHelper,Variable):
         else:
             return encryptObj.getHashPasswd(value, "shadow_ssha256")
 
-    def check(self,value):
+    def check(self, value):
         if not value:
-            raise PasswordError(_("Password for user %s missing")%"root")
+            raise PasswordError(_("Password for user %s missing") % "root")
 
-class VariableClInstallHomeCryptSet(UserHelper,Variable):
+
+class VariableClInstallHomeCryptSet(UserHelper, Variable):
     type = 'bool'
-    opt = ["--crypt-home","-C"]
+    opt = ["--crypt-home", "-C"]
     untrusted = True
 
     def init(self):
@@ -155,19 +160,20 @@ class VariableClInstallHomeCryptSet(UserHelper,Variable):
         return ("off" if self.Get('cl_autologin')
                 else self.Get('cl_home_crypt_set'))
 
-    def check(self,value):
+    def check(self, value):
         if value == "on" and self.Get('cl_autologin'):
             raise VariableError(
                 _("User profile encryption is uncompatible with autologin"))
 
-class VariableClMigrateData(UserHelper,TableVariable):
+
+class VariableClMigrateData(UserHelper, TableVariable):
     """
     User migrate data table
     """
     type = 'table'
-    opt = ["--user","-u"]
+    opt = ["--user", "-u"]
     metavalue = 'USER[:GROUPS]'
-    source = ['cl_migrate_user','cl_migrate_user_groups',
+    source = ['cl_migrate_user', 'cl_migrate_user_groups',
               'cl_migrate_user_pwd']
     untrusted = True
 
@@ -175,15 +181,18 @@ class VariableClMigrateData(UserHelper,TableVariable):
         self.help = _("add a user to the installed system")
         self.label = _("Migrating users")
 
-class VariableClMigrateDataBrief(UserHelper,TableVariable):
+
+class VariableClMigrateDataBrief(UserHelper, TableVariable):
     """
     User migrate data table for brief view
     """
-    source = ['cl_migrate_user','cl_migrate_user_groups']
+    source = ['cl_migrate_user', 'cl_migrate_user_groups']
+
     def init(self):
         self.label = _("Migrating users")
 
-class VariableClMigrateUser(UserHelper,Variable):
+
+class VariableClMigrateUser(UserHelper, Variable):
     """
     Migrate users list
     """
@@ -196,26 +205,28 @@ class VariableClMigrateUser(UserHelper,Variable):
         """
         Migrating users (users above 1000 uid)
         """
-        return filter("root".__ne__,getPasswdUsers())
+        return filter("root".__ne__, getPasswdUsers())
 
-class VariableClMigrateUserGroups(UserHelper,Variable):
+
+class VariableClMigrateUserGroups(UserHelper, Variable):
     """
     Migrate users groups
     """
     type = 'choice-list-list'
-    defaultGroupList = ["users","wheel","audio","cdrom","video",
-                        "cdrw","usb","plugdev","games","lp","scanner","uucp"]
+    defaultGroupList = ["users", "wheel", "audio", "cdrom", "video",
+                        "cdrw", "usb", "plugdev", "games", "lp", "scanner",
+                        "uucp"]
 
     def getDefaultGroups(self):
-        return list(set(self.defaultGroupList)&set(getGroups()))
+        return list(set(self.defaultGroupList) & set(getGroups()))
 
     def init(self):
         self.label = _("Groups")
 
-    def set(self,value):
-        value =  map(lambda x: x \
-                     if x and any(x) else self.getDefaultGroups(),
-               value)
+    def set(self, value):
+        value = map(lambda x: x \
+            if x and any(x) else self.getDefaultGroups(),
+                    value)
         return value
 
     def getPrimaryGroup(self, username):
@@ -229,9 +240,9 @@ class VariableClMigrateUserGroups(UserHelper,Variable):
         User groups
         """
         passwdList = getPasswdUsers()
-        return map(lambda x:(self.getPrimaryGroup(x) + (getUserGroups(x) 
-                   if x in passwdList else self.getDefaultGroups())),
-               self.Get('cl_migrate_user'))
+        return map(lambda x: (self.getPrimaryGroup(x) + (getUserGroups(x)
+                                                         if x in passwdList else self.getDefaultGroups())),
+                   self.Get('cl_migrate_user'))
 
     def choice(self):
         """
@@ -239,7 +250,8 @@ class VariableClMigrateUserGroups(UserHelper,Variable):
         """
         return getGroups()
 
-class VariableClMigrateUserPwd(UserHelper,Variable):
+
+class VariableClMigrateUserPwd(UserHelper, Variable):
     """
     Migrate users who need to change passwords
     """
@@ -257,16 +269,16 @@ class VariableClMigrateUserPwd(UserHelper,Variable):
         if os.access(fileName, os.R_OK):
             migrateusers = self.Get("cl_migrate_user")
             if migrateusers:
-                lenData=9
-                shadowData = filter(lambda x: len(x)==lenData,
+                lenData = 9
+                shadowData = filter(lambda x: len(x) == lenData,
                                     map(lambda x: x.rstrip().split(":"),
-                                    open(fileName)))
+                                        open(fileName)))
                 shadowData = filter(lambda x: x[0] in migrateusers, shadowData)
                 shadowData = map(lambda x: (x[0], x[1]), shadowData)
                 shadowUsers = map(lambda x: x[0], shadowData)
                 for userName in migrateusers:
                     if userName in shadowUsers:
-                        userData = filter(lambda x: x[0]==userName,
+                        userData = filter(lambda x: x[0] == userName,
                                           shadowData)
                         hashPwd = userData[0][1]
                         retList.append(hashPwd)
@@ -274,34 +286,35 @@ class VariableClMigrateUserPwd(UserHelper,Variable):
                         retList.append("")
         return retList
 
-    def check(self,value):
+    def check(self, value):
         """
         Check exists password for all migrate users
         """
-        for user,pwd in zip(self.Get('cl_migrate_user'),value):
+        for user, pwd in zip(self.Get('cl_migrate_user'), value):
             if not pwd:
                 raise PasswordError(
-                    _("Password for user %s missing")%user)
+                    _("Password for user %s missing") % user)
 
-    def set(self,value):
+    def set(self, value):
         """
         Encrypt passwords
         """
         reCheck = re.compile("^\$[^$]+\$[^$]+\$.*$")
         encryptObj = encrypt()
 
-        return map(lambda x:x if reCheck.match(x) or not x else \
-                         encryptObj.getHashPasswd(x, "shadow_ssha256"),
-               value)
+        return map(lambda x: x if reCheck.match(x) or not x else \
+            encryptObj.getHashPasswd(x, "shadow_ssha256"),
+                   value)
 
-class VariableClAutologin(UserHelper,Variable):
+
+class VariableClAutologin(UserHelper, Variable):
     """
     Autologin variable (contains user name for autologin) or
 
     empty string if disable
     """
     type = 'choiceedit'
-    opt = ["--autologin",'-A']
+    opt = ["--autologin", '-A']
     metavalue = "USER"
     xorg_need = True
 
@@ -311,13 +324,13 @@ class VariableClAutologin(UserHelper,Variable):
 
     def get(self):
         # autologin enable for livecd and all install type CMC
-        cmdDomainSet = (getValueFromCmdLine("calculate","domain_pw") or 
-                        getValueFromCmdLine("calculate","domain") or "")
-        if (not cmdDomainSet and 
-            self.Get('os_install_root_type') == "livecd" ) or \
-            self.Get('os_install_linux_shortname') == "CMC":
+        cmdDomainSet = (getValueFromCmdLine("calculate", "domain_pw") or
+                        getValueFromCmdLine("calculate", "domain") or "")
+        if (not cmdDomainSet and
+                    self.Get('os_install_root_type') == "livecd") or \
+                        self.Get('os_install_linux_shortname') == "CMC":
             nonRootUsers = filter(lambda x: x != "root",
-                           self.Get('cl_migrate_user'))
+                                  self.Get('cl_migrate_user'))
             if nonRootUsers:
                 return nonRootUsers[0]
         else:
@@ -325,19 +338,20 @@ class VariableClAutologin(UserHelper,Variable):
         return ""
 
     def set(self, value):
-        return {'none':''}.get(value, value)
+        return {'none': ''}.get(value, value)
 
     def choice(self):
-        return [""]+filter(lambda x:x != "root",self.Get('cl_migrate_user'))
+        return [""] + filter(lambda x: x != "root", self.Get('cl_migrate_user'))
 
-    def check(self,value):
+    def check(self, value):
         """
         Autologin only for migrated non-root users
         """
         if value and not value in self.Get('cl_migrate_user'):
-            raise VariableError(_("User %s does not exist")%value)
+            raise VariableError(_("User %s does not exist") % value)
         if value == "root":
-            raise VariableError(_("Autologin is unavailable for user %s")%value)
+            raise VariableError(
+                _("Autologin is unavailable for user %s") % value)
 
     def humanReadable(self):
         return self.Get() or _("Not used")
@@ -348,13 +362,14 @@ class VariableClAutologin(UserHelper,Variable):
         """
         try:
             if (self.Get('cl_action') == 'merge' and
-                self.Get('client.cl_remote_host')):
+                    self.Get('client.cl_remote_host')):
                 return \
                     _("The autologin is not available with domain workstations")
         except DataVarsError:
             pass
         return UserHelper.uncompatible(self)
 
+
 class VariableClInstallAutoupdateSet(Variable):
     """
     (on or off) autoupdate config from install program for install
@@ -362,53 +377,62 @@ class VariableClInstallAutoupdateSet(Variable):
     type = "bool"
     value = "off"
 
+
 class VariableOsInstallMakeopts(Variable):
     """
     Make.conf makeopts
     """
+
     def get(self):
         cpunum = self.Get('hr_cpu_num')
         if cpunum == "1":
             return "-j1"
         else:
-            return "-j%d"%(int(cpunum)+1)
+            return "-j%d" % (int(cpunum) + 1)
+
 
 class VariableOsGrubConf(ReadonlyVariable):
     """
     DEPRICATED content of current grub.conf
     """
 
+
 class VariableOsInstallGrubDevicemapConf(ReadonlyVariable):
     """
     DEPRICATED content of device.map file for grub
     """
     os_install_grub_devicemap_conf = {}
 
+
 class VariableClDistfilesPath(Variable):
     """
     DISTFILES path
     """
     value = '/var/calculate/remote/distfiles'
 
+
 class VariableClPkgdirPath(Variable):
     """
     PKGDIR path
     """
+
     def get(self):
         return "/var/calculate/remote/packages/%s/%s" % (
-                self.Get('os_install_linux_shortname'),
-                self.Get('os_install_arch_machine'))
+            self.Get('os_install_linux_shortname'),
+            self.Get('os_install_arch_machine'))
+
 
 class VariableClInstallDevFrom(Variable):
     """
     Root device of previous installed os
     """
-    def set(self,value):
+
+    def set(self, value):
         """
         If device in calculate3.env dev_from not exists set ''
         """
         if value:
-            value = getUdevDeviceInfo(name=value).get('DEVNAME',value)
+            value = getUdevDeviceInfo(name=value).get('DEVNAME', value)
         if value in self.Get('os_disk_dev'):
             return value
         else:
@@ -422,10 +446,12 @@ class VariableClInstallDevFrom(Variable):
                                limit=1)
         return ""
 
+
 class VariableOsNvidiaMask(ReadonlyVariable):
     """
     Get nvidia card mask versions
     """
+
     def get(self):
         image = self.Get('cl_image')
         try:
@@ -436,32 +462,35 @@ class VariableOsNvidiaMask(ReadonlyVariable):
                 chrootPath = self.Get("cl_chroot_path")
             nvidiaeclass = path.join(chrootPath,
                                      'usr/portage/eclass/nvidia-driver.eclass')
-            if not os.access(nvidiaeclass,os.R_OK):
+            if not os.access(nvidiaeclass, os.R_OK):
                 return ""
             category = "0300"
             vendor = "10de:"
             lsPciProg = getProgPath("/usr/sbin/lspci")
-            nvidiacards = filter(lambda x:" %s: "%category in x,
-                          process(lsPciProg,"-d",vendor,"-n"))
+            nvidiacards = filter(lambda x: " %s: " % category in x,
+                                 process(lsPciProg, "-d", vendor, "-n"))
             if not nvidiacards:
                 return ""
             cardsid = \
-                map(lambda x:x.groups()[0],
-                filter(lambda x:x,
-                map(lambda x:re.search("[0-9a-fA-F]{4}:([0-9a-fA-F]{4})",x),
-                nvidiacards)))
+                map(lambda x: x.groups()[0],
+                    filter(lambda x: x,
+                           map(lambda x: re.search(
+                               "[0-9a-fA-F]{4}:([0-9a-fA-F]{4})", x),
+                               nvidiacards)))
             if not cardsid:
                 return ""
             eclassdata = readFile(nvidiaeclass)
             drv_categories = re.findall('^drv_([^=]+)="', eclassdata, re.M)
-            drvs = map(lambda x:(x[0],x[1].replace('\\\n','').split()),
-                   re.findall('\ndrv_(%s)="(.*?)"'%"|".join(drv_categories),
-                                   eclassdata,re.S))
+            drvs = map(lambda x: (x[0], x[1].replace('\\\n', '').split()),
+                       re.findall(
+                           '\ndrv_(%s)="(.*?)"' % "|".join(drv_categories),
+                           eclassdata, re.S))
             mask_categories = re.findall('^mask_([^=]+)="', eclassdata, re.M)
-            masks = dict(map(lambda x:(x[0],x[1].replace('\\\n','')),
-                    re.findall('\nmask_(%s)="(.*?)"'%"|".join(drv_categories),
-                                   eclassdata,re.S)))
-            drvsForCardsid = filter(lambda x:set(x[1])&set(cardsid),drvs)
+            masks = dict(map(lambda x: (x[0], x[1].replace('\\\n', '')),
+                             re.findall('\nmask_(%s)="(.*?)"' % "|".join(
+                                 drv_categories),
+                                        eclassdata, re.S)))
+            drvsForCardsid = filter(lambda x: set(x[1]) & set(cardsid), drvs)
             if drvsForCardsid and drvsForCardsid[0][0] in masks:
                 return masks[drvsForCardsid[0][0]]
         finally:
@@ -469,6 +498,7 @@ class VariableOsNvidiaMask(ReadonlyVariable):
                 image.close()
         return ""
 
+
 class VariableOsInstallLvmSet(ReadonlyVariable):
     """
     Using lvm
@@ -482,6 +512,7 @@ class VariableOsInstallLvmSet(ReadonlyVariable):
         else:
             return "off"
 
+
 class VariableOsInstallMdadmSet(ReadonlyVariable):
     """
     Using mdadm
@@ -495,23 +526,27 @@ class VariableOsInstallMdadmSet(ReadonlyVariable):
         else:
             return "off"
 
+
 class VariableClChrootGrub(ReadonlyVariable):
     """
     Chroot for grub-mkconfig
     """
+
     def get(self):
         if self.Get('os_install_scratch') == "on":
             if self.Get('cl_action') == 'system':
                 return self.Get('cl_target').mdirectory
             else:
-                return path.join(self.Get('cl_chroot_path'),"mnt/scratch")
+                return path.join(self.Get('cl_chroot_path'), "mnt/scratch")
         else:
             return self.Get('cl_chroot_path')
 
+
 class VariableOsGrub2Path(Variable):
     """
     Get Grub2 Install cmd (grub-install or grub2-install)
     """
+
     def get(self):
         # find grub2-install
         grubInstall = getProgPath('/usr/sbin/grub2-install')
@@ -519,11 +554,12 @@ class VariableOsGrub2Path(Variable):
             return grubInstall
         # find grub-install and check, that this is grub2-install (ver 1.99)
         grubInstall = getProgPath('/usr/sbin/grub-install')
-        if grubInstall and filter(lambda x:"1.99" in x or "2." in x,
-                           process(grubInstall,'--version')):
+        if grubInstall and filter(lambda x: "1.99" in x or "2." in x,
+                                  process(grubInstall, '--version')):
             return grubInstall
         return ""
 
+
 class VariableClSetup(Variable):
     """
     Type of setup
@@ -543,13 +579,14 @@ class VariableClSetup(Variable):
                    'audio': _("audio parameters"),
                    'session': _("session settings"),
                    'users': _("user settings")}
-        return mapType.get(self.Get(),"")
+        return mapType.get(self.Get(), "")
 
-    def check(self,value):
+    def check(self, value):
         if value == "boot" and self.Get('os_install_root_type') == 'livecd':
             raise VariableError(
                 _("Boot configuration is not available on a LiveCD"))
 
+
 class VariableClLive(Variable):
     """
     Apply live templates
@@ -562,6 +599,7 @@ class VariableClLive(Variable):
         self.label = _("Configure dynamic options only")
         self.help = _("configure dynamic options only")
 
+
 class VariableOsInstallPxe(Variable):
     """
     Installation for PXE loading
@@ -570,25 +608,29 @@ class VariableOsInstallPxe(Variable):
     value = "off"
     untrusted = True
 
-    def check(self,value):
+    def check(self, value):
         if value == "on":
             if self.Get('os_linux_system') != "server":
                 raise VariableError(
-                    _("PXE install is available for Calculate Directory Server only")+'.')
-            for pkg in ['net-misc/dhcp','net-ftp/tftp-hpa','net-fs/nfs-utils']:
+                    _("PXE install is available for Calculate "
+                      "Directory Server only") + '.')
+            for pkg in ['net-misc/dhcp', 'net-ftp/tftp-hpa',
+                        'net-fs/nfs-utils']:
                 if not isPkgInstalled(pkg):
                     raise VariableError(
-                       _("For PXE install, you need to install package %s")
-                            %pkg)
+                        _("For PXE install, you need to install package %s")
+                        % pkg)
             try:
-                config = cl_template.iniParser('/etc/calculate/calculate.env')
-                val = config.getVar('server','sr_dhcp_set')
+                config = cl_ini_parser.iniParser('/etc/calculate/calculate.env')
+                val = config.getVar('server', 'sr_dhcp_set')
                 if val.encode('utf-8') == "on":
                     return
-            except:
+            except Exception:
                 pass
             raise VariableError(
-                _("PXE install is only available if the DHCP service has been configured first"))
+                _("PXE install is only available if the DHCP "
+                  "service has been configured first"))
+
 
 class VariableOsInstallPxePath(Variable):
     """
@@ -602,11 +644,12 @@ class VariableOsInstallPxePath(Variable):
         self.label = _("Installation path")
         self.help = _("path for PXE install")
 
+
 class VariableOsInstallUefiSet(Variable):
     """
     Install in UEFI
     """
-    type  = "bool"
+    type = "bool"
     opt = ['--uefi']
 
     def init(self):
@@ -618,24 +661,24 @@ class VariableOsInstallUefiSet(Variable):
             return self.Get('cl_autopartition_uefi_set')
         else:
             if self.Get('os_install_disk_efi') or \
-                "/boot/efi" in self.Get('os_location_dest'):
+                            "/boot/efi" in self.Get('os_location_dest'):
                 if self.Get('os_install_arch_machine') == 'x86_64' and \
-                    self.Get('os_install_root_type') != 'flash':
+                                self.Get('os_install_root_type') != 'flash':
                     return self.Get('os_uefi_set')
         return 'off'
 
-    def check(self,value):
+    def check(self, value):
         if value == 'on':
             if self.Get('os_uefi_set') == 'off' and \
-                self.Get('os_install_root_type') == 'hdd':
+                            self.Get('os_install_root_type') == 'hdd':
                 raise VariableError(
-                  _("Your system must be loaded in UEFI for using this "
-                    "bootloader"))
+                    _("Your system must be loaded in UEFI for using this "
+                      "bootloader"))
             if not 'gpt' in self.Get('os_device_table'):
                 raise VariableError(
                     _("GPT is needed for using the UEFI bootloader"))
             if not (self.Get('os_install_disk_efi') or
-                "/boot/efi" in self.Get('os_location_dest')):
+                            "/boot/efi" in self.Get('os_location_dest')):
                 raise VariableError(
                     _("A EF00 partition is needed for using "
                       "the UEFI bootloader"))
@@ -658,20 +701,22 @@ class VariableOsInstallUefiSet(Variable):
                 _("This option not used for Flash install")
         return ""
 
+
 class VariableOsInstallUefiBriefSet(VariableOsInstallUefiSet):
     def uncompatible(self):
         if self.Get('os_install_root_type') == 'flash':
             return _("This option not used for Flash install")
         return ""
-    
+
     def get(self):
         return self.Get('os_install_uefi_set')
 
+
 class VariableOsInstallGrubTerminal(Variable):
     """
     Gfxmode
     """
-    type  = "choice"
+    type = "choice"
     opt = ['--grub-terminal']
     metavalue = "TERMINAL"
 
@@ -685,16 +730,16 @@ class VariableOsInstallGrubTerminal(Variable):
             return 'console'
         grubDefault = path.join(self.Get('cl_chroot_path'),
                                 'etc/default/grub')
-        if getValueFromConfig(grubDefault,'GRUB_TERMINAL') == 'console':
+        if getValueFromConfig(grubDefault, 'GRUB_TERMINAL') == 'console':
             return 'console'
         grubCfg = '/boot/grub/grub.cfg'
-        if re.search('^terminal_output\s*console',readFile(grubCfg),re.M):
+        if re.search('^terminal_output\s*console', readFile(grubCfg), re.M):
             return 'console'
 
         return 'gfxterm'
 
     def choice(self):
-        return ['gfxterm','console']
+        return ['gfxterm', 'console']
 
     def uncompatible(self):
         """
@@ -704,6 +749,7 @@ class VariableOsInstallGrubTerminal(Variable):
             return _("Grub configuration unavailable for Flash install")
         return ""
 
+
 class PackageCheckVariable(ReadonlyVariable):
     """
     Конструктор для переменных проверки установлен ли пакет
@@ -721,13 +767,13 @@ class PackageCheckVariable(ReadonlyVariable):
                 if image:
                     with image as distr:
                         distrPath = image.getDirectory()
-                        if isPkgInstalled(self.package,prefix=distrPath):
+                        if isPkgInstalled(self.package, prefix=distrPath):
                             return "on"
             else:
                 prefix = self.Get(self.prefix_variable)
                 if isPkgInstalled(self.package, prefix=prefix):
                     return "on"
-        except:
+        except Exception:
             pass
         return "off"
 
@@ -758,6 +804,7 @@ class FlashUncompatible(VariableInterface):
                 _("Update configuration unavailable for Flash install")
         return ""
 
+
 try:
     import calculate.update.variables.update as update
 
@@ -767,17 +814,17 @@ try:
             return self.Get('update.cl_update_autocheck_set')
 
     class VariableClInstallAutocheckInterval(FlashUncompatible,
-            update.VariableClUpdateAutocheckInterval):
+                                             update.VariableClUpdateAutocheckInterval):
         def get(self):
             return self.Get('update.cl_update_autocheck_interval')
 
     class VariableClInstallCleanpkgSet(FlashUncompatible,
-        update.VariableClUpdateCleanpkgSet):
+                                       update.VariableClUpdateCleanpkgSet):
         def get(self):
             return self.Get('update.cl_update_cleanpkg_set')
 
     class VariableClInstallOtherSet(FlashUncompatible,
-        update.VariableClUpdateOtherSet):
+                                    update.VariableClUpdateOtherSet):
         def get(self):
             return self.Get('update.cl_update_other_set')
 
